"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.compile = exports.run = exports.parse = void 0;
const parser_1 = require("./parser");
const runner_1 = require("./runner");
const utils_1 = require("./utils");
class Bigodon {
    constructor() {
        this.helpers = new Map();
        this.parse = (template) => {
            (0, utils_1.ensure)(typeof template === 'string', 'Template must be a string');
            return parser_1.$template.parse(template);
        };
        this.run = async (ast, context) => {
            return await (0, runner_1.run)(ast, context, this.helpers);
        };
        this.compile = (template) => {
            const ast = this.parse(template);
            return (context) => this.run(ast, context);
        };
        this.addHelper = (name, helper) => {
            (0, utils_1.ensure)(typeof name === 'string', 'name must be a string');
            (0, utils_1.ensure)(typeof helper === 'function', 'helper must be a function');
            this.helpers.set(name, helper);
            return this;
        };
    }
}
const defaultBigodon = new Bigodon();
exports.parse = defaultBigodon.parse, exports.run = defaultBigodon.run, exports.compile = defaultBigodon.compile;
exports.default = Bigodon;
