"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.runBlock = void 0;
const _1 = require(".");
async function runBlock(block, context, extraHelpers) {
    const value = await (0, _1.runStatement)(block.expression, context, extraHelpers);
    // Negated blocks
    if (block.isNegated) {
        // Value is true and there is an else block
        if (value && Array.isArray(block.elseStatements)) {
            return await (0, _1.runStatements)(block.elseStatements, context, extraHelpers);
        }
        // Value is true and there is no else block
        if (value) {
            return null;
        }
        // Value is false
        return await (0, _1.runStatements)(block.statements, context, extraHelpers);
    }
    // Falsy value or empty array
    if (!value || (Array.isArray(value) && value.length === 0)) {
        // Value is false and there is an else block
        if (Array.isArray(block.elseStatements)) {
            return await (0, _1.runStatements)(block.elseStatements, context, extraHelpers);
        }
        // Value is false and there is no else block
        return null;
    }
    // Non empty array
    if (Array.isArray(value)) {
        let result = '';
        for (const item of value) {
            let ctx = context;
            if (typeof item === 'object' && item !== null && !Array.isArray(item)) {
                ctx = item;
            }
            result += await (0, _1.runStatements)(block.statements, ctx, extraHelpers);
        }
        return result;
    }
    // Object
    if (typeof value === 'object') {
        return await (0, _1.runStatements)(block.statements, value, extraHelpers);
    }
    // Truthy value
    return await (0, _1.runStatements)(block.statements, context, extraHelpers);
}
exports.runBlock = runBlock;
